.. _index:

Documentation for *species*
===========================

*species* is a toolkit for atmospheric characterization of directly imaged exoplanets. The package has been developed and is maintained by |stolker|.

.. |stolker| raw:: html

	<a href="https://home.strw.leidenuniv.nl/~stolker/" target="_blank">Tomas Stolker</a>

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   tutorials/running_species.ipynb

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   overview
   configuration
   database
   tutorials
   modules

.. toctree::
   :maxdepth: 2
   :caption: About species

   contributing
   about
